@@ -92,8 +92,11 @@ void overview_coordinate_update(cache_context_t *context) {
 			(GtkCallback)gtk_widget_destroy, NULL);
 
   /* update distance/etc */
-  bearing_fill_hbox(context->bearing_hbox, context->appdata, 
-		    *get_pos(context->appdata), notes_get_pos(context)); 
+  if(!isnan(context->cache->pos.lat) && 
+     !isnan(context->cache->pos.lon)) 
+    bearing_fill_hbox(context->bearing_hbox, context->appdata, 
+		      *get_pos(context->appdata), notes_get_pos(context)); 
+
   gtk_widget_show_all(context->bearing_hbox);
 }
 
@@ -212,10 +215,12 @@ static GtkWidget *cache_overview(cache_context_t *context) {
        context->pos_lon_label = pos_lon(cache->pos.lon, SIZE_BIG, strike));
 
   /* but calculations may be done with respect to the overriden one */
-  context->bearing_hbox = gtk_hbox_new(FALSE, 0);
-  bearing_fill_hbox(context->bearing_hbox, appdata, *refpos, 
-		    gpx_cache_pos(cache));
-  gtk_box_pack_start_defaults(GTK_BOX(ivbox), context->bearing_hbox);
+  if(!isnan(cache->pos.lat) && !isnan(cache->pos.lon)) {
+    context->bearing_hbox = gtk_hbox_new(FALSE, 0);
+    bearing_fill_hbox(context->bearing_hbox, appdata, *refpos, 
+		      gpx_cache_pos(cache));
+    gtk_box_pack_start_defaults(GTK_BOX(ivbox), context->bearing_hbox);
+  }
 
   gtk_table_attach_defaults(GTK_TABLE(table), ivbox, 3,4,0,2);
  
@@ -349,7 +354,7 @@ static GtkWidget *cache_wpts(appdata_t *appdata, wpt_t *wpt) {
       GtkTextBuffer *buffer = gtk_text_buffer_new(NULL);
       gtk_text_buffer_set_text(buffer, wpt->desc, strlen(wpt->desc));
 
-#ifndef USE_MAEMO
+#ifndef USE_HILDON_TEXT_VIEW
       GtkWidget *textview = gtk_text_view_new_with_buffer(buffer);
 #else
       GtkWidget *textview = hildon_text_view_new();
@@ -368,7 +373,7 @@ static GtkWidget *cache_wpts(appdata_t *appdata, wpt_t *wpt) {
     if(wpt->cmt) {
       GtkTextBuffer *buffer = gtk_text_buffer_new(NULL);
       gtk_text_buffer_set_text(buffer, wpt->cmt, strlen(wpt->cmt));
-#ifndef USE_MAEMO
+#ifndef USE_HILDON_TEXT_VIEW
       GtkWidget *textview = gtk_text_view_new_with_buffer(buffer);
 #else
       GtkWidget *textview = hildon_text_view_new();
@@ -665,14 +670,33 @@ void cache_dialog(appdata_t *appdata, cache_t *cache) {
 
 #else
 #ifdef USE_STACKABLE_WINDOW
+static void on_cache_destroy (GtkWidget *widget, appdata_t *appdata) {
+  appdata->cur_cache = NULL;
+
+  /* restore cur_view */
+  appdata->cur_view = g_object_get_data(G_OBJECT(widget), "cur_view");
+}
+
 void cache_dialog(appdata_t *appdata, cache_t *cache) {
   GtkWidget *window = hildon_stackable_window_new();
 
-  gtk_window_set_title(GTK_WINDOW(window), cache->name);
+  /* store last "cur_view" in window */
+  g_object_set_data(G_OBJECT(window), "cur_view", appdata->cur_view);
+
+  appdata->cur_cache = cache;
+  char *title = g_strdup_printf("GPXView - %s", cache->name);
+  gtk_window_set_title(GTK_WINDOW(window), title);
+  g_free(title);
 
   /* create cache visualization widget */
-  gtk_container_add(GTK_CONTAINER(window), 
-		    cache_view(appdata, cache));
+  appdata->cur_view = cache_view(appdata, cache);
+  gtk_container_add(GTK_CONTAINER(window), appdata->cur_view);
+
+  hildon_window_set_app_menu(HILDON_WINDOW(window), 
+			     menu_create(appdata, MENU_CACHE));
+
+  g_signal_connect(G_OBJECT(window), "destroy", 
+		   G_CALLBACK(on_cache_destroy), appdata);
 
   gtk_widget_show_all(window);
 }
