@@ -1493,9 +1493,6 @@ static void
 cb_menu_export_log(GtkWidget *widget, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
   notes_log_export(appdata);
-#ifdef USE_STACKABLE_WINDOW
-  hildon_window_stack_pop_1 (hildon_window_stack_get_default());
-#endif
 }
 
 #ifdef USE_MAEMO
@@ -1503,9 +1500,6 @@ static void
 cb_menu_export_mmpoi(GtkWidget *widget, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
   mmpoi_export(appdata);
-#ifdef USE_STACKABLE_WINDOW
-  hildon_window_stack_pop_1 (hildon_window_stack_get_default());
-#endif
 }
 #endif
 
@@ -1513,33 +1507,21 @@ static void
 cb_menu_export_garmin(GtkWidget *widget, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
   garmin_export(appdata);
-#ifdef USE_STACKABLE_WINDOW
-  hildon_window_stack_pop_1 (hildon_window_stack_get_default());
-#endif
 }
 
 static void 
 cb_menu_geomath(GtkWidget *window, gpointer data) {
   geomath_dialog((appdata_t *)data);
-#ifdef USE_STACKABLE_WINDOW
-  hildon_window_stack_pop_1 (hildon_window_stack_get_default());
-#endif
 }
 
 static void 
 cb_menu_geotext(GtkWidget *window, gpointer data) {
   geotext_dialog((appdata_t *)data);
-#ifdef USE_STACKABLE_WINDOW
-  hildon_window_stack_pop_1 (hildon_window_stack_get_default());
-#endif
 }
 
 static void 
 cb_menu_precpos(GtkWidget *window, gpointer data) {
   precise_position((appdata_t *)data);
-#ifdef USE_STACKABLE_WINDOW
-  hildon_window_stack_pop_1 (hildon_window_stack_get_default());
-#endif
 }
 
 #ifdef USE_STACKABLE_WINDOW
@@ -1552,7 +1534,7 @@ static GtkWidget *export_menu_create(appdata_t *appdata) {
 	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 	    _("Export to Maemo Mapper"),
 	    _("Save a Maemo Mapper POI file"));
-  g_signal_connect(button, "clicked", 
+  g_signal_connect_after(button, "clicked", 
 		   G_CALLBACK(cb_menu_export_mmpoi), appdata); 
   hildon_app_menu_append(menu, GTK_BUTTON(button));
 
@@ -1561,7 +1543,7 @@ static GtkWidget *export_menu_create(appdata_t *appdata) {
 	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 	    _("Export Field Notes"),
 	    _("Save a Garmin Field Notes file"));
-  g_signal_connect(button, "clicked", 
+  g_signal_connect_after(button, "clicked", 
 		   G_CALLBACK(cb_menu_export_log), appdata); 
   hildon_app_menu_append(menu, GTK_BUTTON(button));
 
@@ -1570,7 +1552,7 @@ static GtkWidget *export_menu_create(appdata_t *appdata) {
 	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 	    _("Export Garmin GPX"),
 	    _("Save modified waypoints in GPX file"));
-  g_signal_connect(button, "clicked", 
+  g_signal_connect_after(button, "clicked", 
 		   G_CALLBACK(cb_menu_export_garmin), appdata); 
   hildon_app_menu_append(menu, GTK_BUTTON(button));
 
@@ -1594,14 +1576,15 @@ static GtkWidget *tools_menu_create(appdata_t *appdata) {
   GtkWidget *button;
   HildonAppMenu *menu = HILDON_APP_MENU(hildon_app_menu_new());
 
-  gtk_window_set_title(GTK_WINDOW(menu), "Tools");
+  /* the following doesn't have an effect */
+  //  gtk_window_set_title(GTK_WINDOW(menu), "Tools");
 
   button = hildon_button_new_with_text(
 	    HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH,
 	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 	    _("Geomath"),
 	    _("Geocoordinate calculation"));
-  g_signal_connect(button, "clicked", 
+  g_signal_connect_after(button, "clicked", 
 		   G_CALLBACK(cb_menu_geomath), appdata); 
   hildon_app_menu_append(menu, GTK_BUTTON(button));
 
@@ -1611,7 +1594,7 @@ static GtkWidget *tools_menu_create(appdata_t *appdata) {
 	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 	    _("Geotext"),
 	    _("Text analysis"));
-  g_signal_connect(button, "clicked", 
+  g_signal_connect_after(button, "clicked", 
 		   G_CALLBACK(cb_menu_geotext), appdata); 
   hildon_app_menu_append(menu, GTK_BUTTON(button));
   
@@ -1621,7 +1604,7 @@ static GtkWidget *tools_menu_create(appdata_t *appdata) {
 	    HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 	    _("Precise Position"),
 	    _("Calculate a precise GPS position"));
-  g_signal_connect(button, "clicked", 
+  g_signal_connect_after(button, "clicked", 
 		   G_CALLBACK(cb_menu_precpos), appdata); 
   hildon_app_menu_append(menu, GTK_BUTTON(button));
 
